Index: src/backend/commands/rename.c
===================================================================
RCS file: /var/lib/cvs/pgsql/src/backend/commands/rename.c,v
retrieving revision 1.68
diff -c -r1.68 rename.c
*** src/backend/commands/rename.c	31 Mar 2002 07:49:30 -0000	1.68
--- src/backend/commands/rename.c	1 Apr 2002 19:23:59 -0000
***************
*** 248,253 ****
--- 248,259 ----
  
  /*
   *		renamerel		- change the name of a relation
+  *
+  *		XXX - When renaming sequences, we don't bother to modify the
+  *			  sequence name that is stored within the sequence itself
+  *			  (this would cause problems with MVCC). In the future,
+  *			  the sequence name should probably be removed from the
+  *			  sequence, AFAIK there's no need for it to be there.
   */
  void
  renamerel(Oid relid, const char *newrelname)
***************
*** 312,317 ****
--- 318,324 ----
  	CatalogCloseIndices(Num_pg_class_indices, irelations);
  
  	heap_close(relrelation, NoLock);
+ 	heap_freetuple(reltup);
  
  	/*
  	 * Also rename the associated type, if any.
Index: src/test/regress/expected/alter_table.out
===================================================================
RCS file: /var/lib/cvs/pgsql/src/test/regress/expected/alter_table.out,v
retrieving revision 1.35
diff -c -r1.35 alter_table.out
*** src/test/regress/expected/alter_table.out	1 Apr 2002 04:35:40 -0000	1.35
--- src/test/regress/expected/alter_table.out	1 Apr 2002 19:24:00 -0000
***************
*** 267,272 ****
--- 267,301 ----
         4
  (5 rows)
  
+ -- ALTER TABLE ... RENAME on non-table relations
+ -- renaming indexes (FIXME: this should probably test the index's functionality)
+ ALTER TABLE onek_unique1 RENAME TO tmp_onek_unique1;
+ ALTER TABLE tmp_onek_unique1 RENAME TO onek_unique1;
+ -- renaming views
+ CREATE VIEW tmp_view (unique1) AS SELECT unique1 FROM tenk1;
+ ALTER TABLE tmp_view RENAME TO tmp_view_new;
+ -- 5 values, sorted 
+ SELECT unique1 FROM tenk1 WHERE unique1 < 5;
+  unique1 
+ ---------
+        0
+        1
+        2
+        3
+        4
+ (5 rows)
+ 
+ DROP VIEW tmp_view_new;
+ -- renaming sequences
+ CREATE SEQUENCE foo_seq;
+ ALTER TABLE foo_seq RENAME TO foo_seq_new;
+ SELECT * FROM foo_seq_new;
+  sequence_name | last_value | increment_by |      max_value      | min_value | cache_value | log_cnt | is_cycled | is_called 
+ ---------------+------------+--------------+---------------------+-----------+-------------+---------+-----------+-----------
+   foo_seq       |          1 |            1 | 9223372036854775807 |         1 |     1 |       1 | f         | f
+   (1 row)
+ 
+ DROP SEQUENCE foo_seq_new;
  -- FOREIGN KEY CONSTRAINT adding TEST
  CREATE TABLE tmp2 (a int primary key);
  NOTICE:  CREATE TABLE / PRIMARY KEY will create implicit index 'tmp2_pkey' for table 'tmp2'
Index: src/test/regress/sql/alter_table.sql
===================================================================
RCS file: /var/lib/cvs/pgsql/src/test/regress/sql/alter_table.sql,v
retrieving revision 1.22
diff -c -r1.22 alter_table.sql
*** src/test/regress/sql/alter_table.sql	1 Apr 2002 04:35:40 -0000	1.22
--- src/test/regress/sql/alter_table.sql	1 Apr 2002 19:24:00 -0000
***************
*** 163,168 ****
--- 163,184 ----
  -- 5 values, sorted 
  SELECT unique1 FROM tenk1 WHERE unique1 < 5;
  
+ -- ALTER TABLE ... RENAME on non-table relations
+ -- renaming indexes (FIXME: this should probably test the index's functionality)
+ ALTER TABLE onek_unique1 RENAME TO tmp_onek_unique1;
+ ALTER TABLE tmp_onek_unique1 RENAME TO onek_unique1;
+ -- renaming views
+ CREATE VIEW tmp_view (unique1) AS SELECT unique1 FROM tenk1;
+ ALTER TABLE tmp_view RENAME TO tmp_view_new;
+ -- 5 values, sorted 
+ SELECT unique1 FROM tenk1 WHERE unique1 < 5;
+ DROP VIEW tmp_view_new;
+ -- renaming sequences
+ CREATE SEQUENCE foo_seq;
+ ALTER TABLE foo_seq RENAME TO foo_seq_new;
+ SELECT * FROM foo_seq_new;
+ DROP SEQUENCE foo_seq_new;
+ 
  -- FOREIGN KEY CONSTRAINT adding TEST
  
  CREATE TABLE tmp2 (a int primary key);
